% Universitt Hamburg, Fachbereich Informatik, AB TECH
% T4-Praktikum: erster Termin (und evtl. zweiter) Termin
% Autor: Klaus von der Heide, e-mail:  v.d.heide@on-line.de
% Folgende Funktionen wurden von anderen Autoren bernommen:
% wavreadx, viterbi und Zubehr.
%
%
% Audio
%   wavreadx       - Lesen von 8- und 16-Bit-WAV-Dateien
%
% Codes
%   faltcode       - Codierung mit Faltungscode
%   faltcodesim    - Simulation der Faltungscodierung und Decodierung
%   faltpoly       - Polynome fr Faltungscodes
%   hamming7_4     - Matrix der Codewrter des (7,4)-Hammingcodes
%   softdecode     - Decodierung durch Korrelation 
%   viterbi        - Viterbi-Algorithmus zur Soft-Decodierung
%
% Filter
%   cosrolloff     - Berechnung der Kosinus-Rolloff-Funktion
%   crfir          - Entwurf von Cosinus-Rolloff-Filtern
%   filterplot     - universelle Darstellung von Filtergngen
%   wcrfir         - Entwurf von Wurzel-Cosinus-Rolloff-Filtern
%
% Informationsreprsentation
%   binvec2num     - Wandlung eines Bitvektors in natrliche Zahl
%   binvec2str     - Wandlung eines Bitvektors in einen ASCII-String
%   bitstuffing    - Bitstuffing und umgekehrt
%   int2gf         - Wandlung Zahl nach Stellensystem bzgl. Basis gf
%   limprec        - Begrenzung auf n Binrstellen
%   num2binvec     - Wandlung Zahl nach Bitvektor
%   str2binvec     - Wandlung String nach Bitvektor
%
% Mathematik
%   fourierplot    - Darstellung von Funktionen und deren Fouriertransformierten
%   ifourierplot   - Darstellung von komplexen Funktionen und Transformierten
%   spctrm         - Berechnung des Betragsspectrums an Sttzstellen
%   nyquistinterpol - Shannoninterpolation
%
% Modulation und Demodulation
%   amplmod        - Demo: Amplitudenmodulation und Demodulation
%   freqmod        - Demo: Frequenzmodulation und Demodulation
%   phasenmod      - Demo: Phasenmodulation und Demodulation
%   qammod         - Demo: Quadraturmodulation und Demodulation
%   modspec        - Demonstration der Modulationsarten: Spektren
%   modulation     - Demonstration der Modulationsarten: Hllkurven
%
% Nachrichtentechnik
%   fskrx          - FSK-Empfnger mit Start/Stopp-Synchronisation
%   fsktest        - komplette Datenbertragung mit FSK und Start/Stopp
%   fsktx          - FSK-Sender mit Start/Stopp
%   mpsk_noise     - Signalraumdarstellung von mPSK mit Rauschen
%   nqispectrum    - Spektrum von Shannoninterpolation
%   qam14k4        - 64-Punkte-QAM: Signalraumdiagramm
%   raisedcosine   - Verbindung diskreter Werte durch raised Cosine
%   rcspectrum     - Darstellung des Spektrums fr Raised Cosine
%   schrittsync    - Demo fr Schrittsynchronisation durch kleinste Quadrate
%   startstop      - Demo fr Start/Stopp-Synchronisation
%   txrxfilter     - Demo: Filter, Sendepuls, Augendiagramm, etc.
%   v22bis         - Signalraumdarstellung fr V.22bis
%   v27bis         - Signalraumdarstellung fr V.27bis
%   v29            - Signalraumdarstellung fr V.29
%
% Zufallszahlen und Rauschen
%   add_awgn       - Addition von weissem Gauss-Rauschen
%   randb          - Binres Zufallsmuster
%   randpermut     - Generierung einer zuflligen Permutation der Zahlen 1...n
%   randx          - Zufallsmuster aus vorgegebener Menge
%   ebn2sigma      - Standardabweichung fr AWGN bei gegebenem Eb/No
%
% Signaldarstellung
%   analytsig      - Animierte Signalraumdarstellung
%   abtastanimation - Darstellung eines komplexen Vektors
%   komplexanimat  - Animierte Signalraumdarstellung
%
% Distributionen
%   Dirac          - Dirac'sche Deltafunktion
%   Heaviside      - Heaviside'sche Sprungfunktion
%
% Statistik
%   fehl_vert      - Darstellung von Bitfehlerwahrscheinlichkeiten
%   p_dec_ok       - Wahrscheinlichkeit korrekter Dekodierung fr (n,k)-Code
%   plot_code_gain - Bitfehlerwahrscheinlichkeit fr (n,k)-Code (Plot)
%   p_dec_ok       - Wahrscheinlichkeit richtiger Decodierung eines Codes
%   simsoftdecode  - Simulation von harter und weicher Entscheidung
%
% T4-Praktikum
%   t4_1           - Zeitbereich und Frequenzbereich
%   t4_2           - Abtastung
%   t4_3           - Datenbertragung im Basisband
%   t4_4           - Schrittsynchronisation
%   t4_5           - Modulation
%   t4_6           - Kanalcodierung
%   v21_startstop  - FSK-Modem nach V.21 (benutzt in t4_5)
%
% Hilfsfunktionen
%   delay          - Indexverschiebung bei Vektoren
%   diracpuls      - Approximation des Diracpulses zum Plotten
%   flach          - Wandlung Matrix und bel. Struktur nach Vektor
%   fullscreen     - Erzeugung und Konfektionierung eines Vollformat-Bildes
%   nfach          - Ver-n-fachung jeder Komponente eines Vektors
%   nullein        - Einfgung von Nullen zwischen Vektorkomponenten
%   real2analyt    - Wandlung eines reellen in ein analytisches Signal
%   reverse        - Spiegelung von Vektoren
%   rotatevector   - Rotation der Komponenten eines Vektors um d Stellen
%   screen         - Hilfsfunktion fr Bildschirmeinstellung
%   specrot        - Spektrale Rotation eines Filterfrequenzganges
%   swap           - Vertauschung von Vektorkomponenten
%
% KeyPressFcn
%   anicont        - Geschwindigkeitssteuerung einer Animation
%   hervorhebung   - Hervorheben bestimmter Linienobjekte
%   sichtbarkeit   - Ein- und Ausschalten von Linienobjekten
%   togglevisibility - Ein- und Ausschalten von Linienobjekten
%   xzoom          - Zoom und Scroll in x-Richtung
%   xzoomvis       - Zoom und Scroll in x-Richtung sowie Ein/Ausschalten von Linien
%   zoom3d         - Zoom und Scroll in drei Richtungen
%   
