function abtastanimation(x,velocity,blick,del)
% abtastanimation(x,velocity,blick,del)
% In der Zeitachse animierte Darstellung des abgetasteten Vektors x.
% Im Falle von komplexen Elementen ist die Darstellung 3D, wenn die
% Imaginrteile maximal 0.001 des mittleren Realteil sind jedoch 2D.
% velocity (optional) ist die Geschwindigkeit der Animation (0.1 ... 10). 
% blick gibt optional die Blickrichtung an entsprechend view,
% blick=[90,0] sieht genau lngs der Zeitachse; default=[12,10].
% Anhalten der Animation ist mglich durch Drcken der Taste p.
% Jede Taste startet die Animation wieder.
% Die Animation wird abgebrochen mit der Taste s (danach beliebige Taste).
% Die Geschwindigkeit wird verndert mit den Tasten + und -.
% Der Blickwinkel kann mit den Tasten r l h t verndert werden.
% Wenn die Animation zuende ist, kann das Bild 
% mit den Tasten r l h t sowie mit der Maus gedreht werden.
% Mit del = 0 wird das automatische Lschen des Bildes abgeschaltet.

% K. v. d. Heide,  e-mail:  v.d.heide@on-line.de
%
% Defaults
% ========
fsz = 14;                         % FontSize fr Beschriftung
lw = 1.5;                         % LineWidth
if nargin<1  x = randn(1,50); end % Inputvektor
if nargin<2  velocity = 1;    end % Darstellungsgeschwindigkeit
if nargin<3  blick = [12,10]; end % Blickrichtung falls 3D
if nargin<4  del = 1;         end % Bild automatisch lschen
%
% Signaldarstellung
% =================
rr = all(abs(imag(x))<0.001*mean(abs(real(x)))); % x reell ?
if rr blick = [0 90]; end
switch screen
   case 1
      h1pos = [1 31 800 549];
   case 2
      h1pos = [1 31 1024 718];
   otherwise error('Bildpositionen fr screen nicht angegeben.');
end;
h1=figure;
set(h1,'Name','Zeitbereich','position',h1pos,'Color','w','MenuBar','none',...
       'NumberTitle','off','KeyPressFcn','anicont','UserData',0);
ax= [-1,1,-1,1]*max(abs(x));
axis([1,length(x),ax]);
axis square; axis manual; axis on;
xlabel('Zeit','FontSize',fsz);
ylabel('Realteil','FontSize',fsz);
zlabel('Imaginrteil','FontSize',fsz);
set(h1,'CurrentAxes',gca);
l0=line('Color',0.5*[1 1 1],'EraseMode','none','LineWidth',lw,...
   'LineStyle','-','xdata',[0,0],'ydata',[0,0],'zdata',[0,0]);
l1=line('Color','r','EraseMode','none','LineWidth',lw,...
   'LineStyle','-','xdata',[0,0],'ydata',[0,0],'zdata',[0,0]);
l2=line('Marker','o','Color','r','MarkerSize',5,'EraseMode','none',...
   'LineStyle','none','xdata',[0,0],'ydata',[0,0],'zdata',[0,0],...
   'LineWidth',lw);
l3=line('Marker','o','Color','k','MarkerSize',5,'EraseMode','none',...
   'LineStyle','-','xdata',[0,0],'ydata',[0,0],'zdata',[0,0],...
   'LineWidth',lw);
view(blick);
k = 0;
stop = 0;
while (k<length(x))&stop==0
   k = k+1;
   switch get(h1,'UserData')
      case 1,   velocity = velocity*2;
      case -1,  velocity = velocity/2;
      case 2,   stop = 1;
   end;
   set(h1,'UserData',0)
   for kk = 1:floor(1000/velocity) sin(kk); end; % Dummy
   xd= real(x(k));
   yd= imag(x(k));
   set(l0,'xdata',[k-1,k],'ydata',[0 0],'zdata',[0 0]);
   set(l1,'xdata',[k k],'ydata',[0 xd],'zdata',[0 yd]);
   set(l2,'xdata',k,'ydata',xd,'zdata',yd);
   set(l3,'xdata',k,'ydata',0,'zdata',0);
   drawnow;
end;
d  = 1:length(x);
xd = real(x(d));
yd = imag(x(d));
zrs= zeros(1,length(d));
set(l0,'xdata',[1,k],'ydata',[0 0],'zdata',[0 0]);
line([d;d],[zrs;xd],[zrs;yd],'Color','r','LineWidth',lw);
set(l2,'xdata',d,'ydata',xd,'zdata',yd);
set(l3,'xdata',d,'ydata',zrs,'zdata',zrs);
drawnow
rotate3d on
pause
if del delete(h1); end

