function analytsigd(fsin,f1,f2,snr,m,velocity,blick,nur)
% analytsigd(fsin,f1,f2,snr,m,velocity,blick,nur)
% Demo fr analytische Signale. (Demo auch ohne Parameter) 
% Es wird ein Sinus-Signal der Frequenz fsin erzeugt und 
% ein weisses Rauschen hinzugefgt. Dieses Signal wird mit 
% einem IIR-Bandpass vom Grad 8 und den Passbandgrenzen f1 und f2 
% gefiltert, so dass ein bandbegrenztes Signal mit Signal/Rauschver-
% hltnis snr entsteht. Anschliessend erfolgt die Wandlung in ein 
% analytisches Signal und die Darstellung als Bewegtbild.
% Ist snr > 9999, so wird nur das ungefilterte Signal gezeigt.
% In diesem Fall kann fr fsin optional ein Vektor von zwei Komponenten 
% eingegeben werden: [Frequenz, Phase] (Freqenz; 0 <= Phase < pi).
% m gibt optional die Lnge der darzustellenden Sequenz an (Default=25).
% velocity (optional) ist die Geschwindigkeit der Animation (0.1 ... 10). 
% blick gibt optional die Blickrichtung an entsprechend view,
% blick=[90,0] sieht genau lngs der Zeitachse; default=[12,10].
% Wird nur mit beliebigem Wert angegeben, so erfolgt nur die Darstellung 
% der Animation ohne die Filter.
% Ist nur = 1, so wird das Bild nicht gelscht.
% Einheit von fsin,f1,f2 ist die Nyquistfrequenz = Abtastrate/2;
% das Hilberfilter lsst dabei nur den Bereich 0.02..0.98 zu.
% Zunchst werden der Frequenzgang der benutzten Filter gezeigt und die 
% Spektren des Signals. Nach beliebigem Tastendruck folgt die Animation.
% Anhalten der Animation ist mglich durch Drcken der Taste p.
% Jede Taste startet die Animation wieder.
% Die Animation wird abgebrochen mit der Taste s (danach beliebige Taste).
% Die Geschwindigkeit wird verndert mit den Tasten + und -.
% Der Blickwinkel kann mit den Tasten r l h t verndert werden.
% Wenn die Animation zuende ist, werden die Bilder mit beliebigem 
% Tastendruck gelscht mit Ausnahme des 3D-Bildes. Diese kann dann 
% mit den Tasten r l h t sowie mit der Maus gedreht werden.
% Wird analytsigd ganz ohne Parameter aufgerufen, so wird 
% analytsigd(0.1,0.05,0.15,3,25,1,[12,10],0) dargestellt.
% Der Unterschied zu analytsig besteht darin, dass analytsigd die 
% Ortsvektoren der abgetasteten Werte darstellt anstelle des 
% kontinuierlichen Signals. Ausserdem erbrigt sich die Darstellung 
% des sich drehenden Ortsvektors in einem eigenen Fenster.

% K. v. d. Heide,  e-mail:  v.d.heide@on-line.de
%
% Defaults
lw = 1.5;                      % LineWidth
if nargin<1  fsin = 0.1; end
if nargin<2  f1 = 0.05;  end
if nargin<3  f2 = 0.15;  end
if nargin<4  snr= 10000; end
if nargin<5  m  = 25;    end   % Lnge der Darstellung im Zeitbereich
if nargin<6  velocity=1; end   % Darstellungsgeschwindigkeit
if nargin<7  blick = [12,10]; end
if nargin<8 nur = 0;     end
if snr<0 error('snr kann nicht kleiner als 0 sein'); end;
if length(fsin)==2  fsn = fsin(1); ph = fsin(2); 
else if length(fsin)==1 fsn = fsin; ph = 0; else fsn = 0; ph = 0; end
end
if snr<10000
   if (fsn<0)|(fsn>1) error('fsin nicht im Bereich 0...1'); end;
   if f1<0.02 error('f1 darf nicht kleiner sein als 0.02'); end;
   if f2>0.98 error('f2 darf nicht grsser sein als 0.98'); end;
   if f2-f1 < 0.04 error('f2 - f1 muss grsser als 0.04 sein'); end;
   if (abs(fsin)<f1)|(abs(fsin)>f2) hinweis='Das Signal liegt nicht im Bandpass.', end;
end
fsz = 12;            % FontSize fr Beschriftung
%
%================== Filterentwurf ===================================
ga= 8;               % Filtergrad fr IIR-Bandpass
gh=126;              % Filtergrad fr Hilbertfilter
[ba,aa]=ellip(ga/2,0.5,60,[f1,f2]);      % Bandpassfilterkoeffizienten
bh= remez(gh,[0.1 0.9],[1 1],'Hilbert'); % Hibertfilter
% zum Hilbertfilter passende Verzgerung:
bv=[zeros(1,gh/2),1,zeros(1,gh/2)];      % Koeffiz. der Verzgerung
%
%================== Signalerzeugung =================================
xanf=1300;             % Darstellungsanfang
xend=xanf+m-1;         % Darstellungsende
xe  =xanf+1023;        % Ende fr die 1024-FFT
n = xanf+max(1023,m)+200; % Sample-Lnge
t = 1:n;               % Zeitbereich in Abtastschritten
z = (1024:-1:1)/512;   % Frequenzbereich 0..Abtastfrequenz entspricht 0..2
sn= 1+(f2-f1)*snr;     % SNR auf Bandbreite umrechnen
if length(fsin)>2
   x = filter(ba,aa,fsin);                      % direkter Input
   y = filter(bv,1,x)+i*filter(bh,1,x);         % analytisches Signal
   if length(x)<xe xend = length(x); end        % Darstellung anpassen
else
   if snr>999
      x = cos(pi*fsn*t+ph);                     % nur Cosinus
      y = x + i*sin(pi*fsn*t+ph);               % analytisches Signal
   else
      x = filter(ba,aa,sinnoise(pi*fsn*t,sn));  % Sinus + Rauschen
      y = filter(bv,1,x)+i*filter(bh,1,x);      % analytisches Signal
   end
end
%
%================== Signaldarstellung ===============================
% Die Darstellung erfolgt in zwei Bildschirmen nacheinander. Zunchst 
% der Filterfrequenzgang und die Spektren.
switch screen
   case 1
      h0pos = [1 315 400 265];
      h1pos = [1 31 800 549];
      h2pos = [551 330 250 250];
      h3pos = [1 31 400 265];
      h4pos = [401 31 400 265];
      h5pos = [401 315 400 265];
   case 2
      h0pos = [1 402 512 346];
      h1pos = [1 31 1024 718];
      h2pos = [700 428 320 320];
      h3pos = [1 31 512 346];
      h4pos = [513 31 512 346];
      h5pos = [513 402 512 346];
   otherwise error('Bildpositionen fr screen nicht angegeben.');
end;
if nargin<8   
   h0=figure;
   set(h0,'Name','Filter-Frequenzgang','position',h0pos,'Color','w',...
          'MenuBar','none','NumberTitle','off');
   iirplot(256,0,2,-80,10,[ga,1,ba,aa,gh,1,bh,[1,zeros(1,gh)]]);
   xlabel('Signalfrequenz und Rauschfilter','FontSize',fsz);
   line([abs(fsin),abs(fsin)],[0,0],'LineStyle','none','Color','r','Marker','.','MarkerSize',20);
   legend('Bandpass','Hilbertfilter','Signalfrequenz')
   h3=figure; 
   set(h3,'Name','Spektrum des Realteils','position',h3pos,'MenuBar','none','NumberTitle','off');
   plot(z,abs(fft(real(y(xanf:xe)))));
   xlabel('Spektrum des Realteils','FontSize',fsz);
   h4=figure; 
   set(h4,'Name','Spektrum des Imaginrteils','position',h4pos,'MenuBar','none',...
          'NumberTitle','off');
   plot(z,abs(fft(imag(y(xanf:xe)))));
   xlabel('Spektrum des Imaginrteils','FontSize',fsz);
   h5=figure; 
   set(h5,'Name','Spektrum des analytischen Signals','position',h5pos,'MenuBar','none',...
          'NumberTitle','off');
   plot(z,abs(fft(y(xanf:xe))));
   xlabel('Spektrum des analytischen Signals','FontSize',fsz);
   standbild;
end
% Demonstration: Gezeigt wird ein analytisches Signal im Zeitbereich
% v ist ein Faktor fr die Zeitdehnung.
% Es werden v*w Schwingungen abgebildet.
h1=figure;
set(h1,'Name','Zeitbereich','position',h1pos,'Color','w','MenuBar','none',...
       'NumberTitle','off','KeyPressFcn','anicont','UserData',0);
ax= [-1,1,-1,1]*max(abs(y(xanf:xend)));
axis([xanf,xend,ax]);
axis square;
axis manual;
axis on;
xlabel('Zeit','FontSize',fsz);
ylabel('Realteil','FontSize',fsz);
zlabel('Imaginrteil','FontSize',fsz);
set(h1,'CurrentAxes',gca);
l0=line('Color',0.5*[1 1 1],'EraseMode','none','LineWidth',lw,...
   'LineStyle','-','xdata',[0,0],'ydata',[0,0],'zdata',[0,0]);
l1=line('Color','r','EraseMode','none','LineWidth',lw,...
   'LineStyle','-','xdata',[0,0],'ydata',[0,0],'zdata',[0,0]);
l2=line('Marker','o','Color','r','MarkerSize',5,'EraseMode','none',...
   'LineStyle','none','xdata',[0,0],'ydata',[0,0],'zdata',[0,0],...
   'LineWidth',lw);
l3=line('Marker','o','Color','k','MarkerSize',5,'EraseMode','none',...
   'LineStyle','-','xdata',[0,0],'ydata',[0,0],'zdata',[0,0],...
   'LineWidth',lw);
view(blick);
k = xanf;
stop = 0;
while (k<xend)&stop==0
   k = k+1;
   switch get(h1,'UserData')
      case 1,   velocity = velocity*2;
      case -1,  velocity = velocity/2;
      case 2,   stop = 1;
   end;
   set(h1,'UserData',0)
   for kk = 1:floor(1000/velocity) sin(kk); end; % Dummy
   xd= real(y(k));
   yd= imag(y(k));
   set(l0,'xdata',[k-1,k],'ydata',[0 0],'zdata',[0 0]);
   set(l1,'xdata',[k k],'ydata',[0 xd],'zdata',[0 yd]);
   set(l2,'xdata',k,'ydata',xd,'zdata',yd);
   set(l3,'xdata',k,'ydata',0,'zdata',0);
   drawnow;
end;
d  = xanf:k;
xd = real(y(d));
yd = imag(y(d));
zrs= zeros(1,length(d));
set(l0,'xdata',[xanf,k],'ydata',[0 0],'zdata',[0 0]);
line([d;d],[zrs;xd],[zrs;yd],'Color','r','LineWidth',lw);
set(l2,'xdata',d,'ydata',xd,'zdata',yd);
set(l3,'xdata',d,'ydata',zrs,'zdata',zrs);
drawnow
rotate3d on
if nur~=1 pause; end
if nargin<8  delete(h0); delete(h3); delete(h4); delete(h5); end
if nur~=1 delete(h1); end


