function v29(EbNodB,n)
% v29(EbNodB,n)
% Signalraumdarstellung von CCITT V.29 im Rauschen von Eb/N0 = EbNodB [dB].

% Autor: K. von der Heide,  e-mail:  v.d.heide@on-line.de

% Konstanten und Defaults
% =======================
fsiz = 15;                                    % FontSize
if nargin<2  n = 15000;   end
if nargin<1  EbNodB = 20; end

% Symbole in CCITT V.29
% =====================
a = sqrt(4/54);
sig = a*[ 1+1*i; -1+1*i; -1-1*i;  1-1*i;
          3+0*i;  0+3*i; -3+0*i;  0-3*i;
          3+3*i; -3+3*i; -3-3*i;  3-3*i;
          5+0*i;  0+5*i; -5+0*i;  0-5*i];

% Rauschen
% ========
ra  = add_awgn(zeros(1,n),1,EbNodB-3)...      % reell
      + i*add_awgn(zeros(1,n),1,EbNodB-3);    % imaginr

% Signal
% ======
sa = sig(ceil(16*rand(1,n)))';                 % Signal

% Signal + Rauschen
% =================
sr = sa + ra;
mx = max([real(sr),imag(sr)]);

% Darstellung
% ===========
hs = figure; 
fullscreen('Signalraum')
line(real(sr'),imag(sr'),'LineStyle','none','Marker','.')
line([-mx,0;mx,0],[0,-mx;0,mx],'LineStyle','-','Color','r')
axis([-mx,mx,-mx,mx]); axis square; axis off
title(sprintf('Signalraum:  CCITT V29  Eb/No = %4.1f dB',...
      EbNodB),'FontSize',fsiz)
pause
delete(hs)
