% filtertest
% Skript zur Beurteilung von Sendefilter und 
% Empfangsfilter-Kombinationen mit automatischer
% Auswertung.
% Gezeigt werden fr jede Filterkombination fnf Bilder:
%   1. Frequenzgang der Filter
%   2. Sendepuls
%   3. Impuls nach dem Empfangsfilter
%   4. Augendiagramm
%   5. Signale fr eine zufllige Bitsequenz
% Beurteilt werden soll, ob ein benachbartes Bit Einfluss auf 
% die Entscheidung des aktuellen Bits hat. Die ist aus dem 
% Augendiagramm abzulesen (alle Signale schneiden sich in 
% zwei Punkten oder nicht) oder aus dem Impuls nach dem 
% Empfangsfilter (der Puls verluft durch die rot markierten 
% Nullstellen an den Abtastpunkten fr die Nachbarbits).

% Autor:  Klaus von der Heide, e-mail:  v.d.heide@on-line.de

echo off

% Filter
% ======
b{1} = wcrfir(30,0.08,0.5);
b{2} = crfir(14,0.124,0.1);
b{3} = fir1(30,0.127);
b{4} = fir1(30,0.14);
b{5} = ones(1,10)/10;
n = length(b);

% Richtige Ergebnismatrix
% =======================
rmatrix = [1 0 1 0 0;
           0 1 0 0 1;
           1 0 1 0 0;
           0 0 0 0 1;
           0 1 0 1 1];
        
% Permutation der Indices
% =======================
p = randpermut(n);
for k = 1:n  f{k} = b{p(k)}; end
for k = 1:n  temp(k,:) = rmatrix(p(k),:); end
for k = 1:n  richtig(:,k) = temp(:,p(k)); end

% Interaktiver Filtertest
% =======================        
echo on

%  Jetzt die Filterkombinationen bewerten:
%  Die Intersymbolinterferenz soll verschwinden.
%  Dies kann im Augendiagramm und in der Impulsantwort 
%  nach dem Empfangsfilter abgelesen werden.
%  Es ist jeweils eine "0" bzw eine "1" einzugeben
%  Mit der Enter-Taste abschliessen.
echo off

for sf = 1:n
   for ef = sf:n
      txrxfilter(f{sf}, f{ef});
      matrix(sf,ef) = input('   schlecht: 0  / gut: 1  ');
      matrix(ef,sf) = matrix(sf,ef);
   end
end

% Ergebnisprfung und Wiederholung
% ================================
if sum(sum(~matrix==richtig)) > round(n/4)
echo on
   
%  Zu viele Fehler !!!  Bitte noch einmal von vorn beginnen.

echo off
break
end

while ~all(all(matrix==richtig))
   [sf,ef] = find(~matrix==richtig);
   sf = sf(1);
   ef = ef(1);
echo on
   
%  Die folgende Filterkombination wurde falsch bewertet

echo off
   txrxfilter(f{sf}, f{ef});
   matrix(sf,ef) = input('   schlecht: 0  / gut: 1  ');
   matrix(ef,sf) = matrix(sf,ef);
end
echo on

%     ---------------------
%     |  ALLES RICHTIG !  |
%     ---------------------

echo off

