function z = fskrx(signal,f0,baud,filt,bild)
% z = fskrx(signal,f0,baud,filt,bild)
% FSK-Empfnger
% signal :  das Empfangssignal
% f0     :  Trgerfrequenz relativ zur Abtastfrequenz
% baud   :  Baudrate bezogen auf die Abtastfrequenz
% filt   :  Koeffizienten des Empfangsfilters,
%           falls nur ein Wert:  obere Grenze des Empfangstiefpasses
% bild   :  grafische Darstellung falls bild nicht angegeben oder 0 
% z      :  die empfangenen Symbole
% Die Defaultwerte gelten fr V.21 bei der Abtastung mit 8 kHz.

% Autor: Klaus von der Heide, e-mail:  v.d.heide@on-line.de

% Defaults
% ========
g = 30;                              % Filtergrad
if nargin<5 bild = 1; end
if nargin<3 baud = 0.0375; end
if nargin<4 filt = fir1(g,baud); end
if nargin<2   f0 = 0.135;  end
if length(filt)<2  b = fir1(g,filt); else b = filt; end 
if screen==1 pos = [1 430 800 150]; else pos = [1 586 1024 164]; end
schritt = round(1/baud);
t = 0:length(signal) - 1;            % Zeitbereich

% Empfnger und Demodulator
% =========================
z  = exp(i*2*pi*f0*t);               % Trger im Demodulator
y  = signal.*z;                      % Transformation ins Basisband
x  = filter(b,1,y);                  % Empfangsfilter
x  = x(g+1:length(x));               % Abschneiden des Einschwingbereiches
a  = abs(x);                         % Amplitude
w  = x./a;                           % Beseitigung der Amplitudenschwankung
lw = length(w);
wr = real(w);
wi = imag(w);
a  = asin(wr(2:lw).*wi(1:lw-1)-wi(2:lw).*wr(1:lw-1)); % Demodulation
s  = a>0;                            % Datenentscheidung

% Start/Stopp-Synchronisation
% ===========================
bereich= 1:length(s);                % gesamter Zeitbereich
zeiger = 1;                          % Zeiger: noch lesen
abtast = [];                         % Abtastzeitpunkte
while ~all(s(zeiger:length(s)))
   tast   = min(find((bereich>=zeiger).*(s==0))) + round(1.5*schritt) + (0:schritt:7*schritt);
   abtast = [abtast, tast];          % Abtastpunkte
   zeiger = max(tast) + 2*schritt;   % Zeitzeiger   
end
abtast = abtast(1:max(find(abtast<length(s))));
z = s(abtast);                       % Abtastung der Bits

% Grafische Darstellung nur wenn bild~=0
% ======================================
if ~bild  break; end

% Animation
% =========
komplexanimat(x,[1 1 0 0 0 0],10,[60,20],abtast)

% Auswertung
% ==========
fh2 = fullscreen('Binrsignal');
set(fh2,'Position',pos,'KeyPressFcn','zoom3d')
plot(1:length(s),s)
line([0 length(s)],[0 0],'LineStyle',':','Color',0.7*[1 1 1])
lh = line(abtast,s(abtast));
set(lh,'LineStyle','none','Marker','*','MarkerEdgeColor','r')
set(gca,'XLim',[0,length(s)],'YLim',[-0.5,1.5])
