function phasensync(schritt,schrittfehler,txsymb,neutral)
% phasensync(schritt,schrittfehler,txsymb,neutral)
% schritt       :  Symbolschritt in Samples (sinvoll 4...100)
% schrittfehler :  relativer Schrittfehler (sinnvoll <0.0001)
% txsymb        :  Vektor der zu sendenden Symbole
% neutral       :  empfangenes Symbol, wenn keine Sendung
% Defauls sind  :  schritt = 8;  schrittfehler = 0;
%                  txbits  = 16 zufllige Bits; neutral = 0

% Autor: K.von der Heide,  e-mail: v.d.heide@on-line.de

% Defaults
% ========
if nargin<4 neutral = 0; end
if nargin<3 txsymb  = 2*randb(16)-1; end
if nargin<2 schrittfehler = 0; end
if nargin<1 schritt = 8; end
anzsymb = length(txsymb);
symbole = [neutral, txsymb, neutral];  % zu sendende Symbole

% Sender
% ======
vorlauf= neutral*ones(1,ceil(schritt*rand)); % zuflliger Zeitversatz
auslauf= neutral*ones(1,schritt-length(vorlauf)); % Auslauf
signal = [vorlauf,...                  % gesendetes Signal
          raisedcosine(symbole,schritt),auslauf];
       
% Empfnger
% =========
sigsqr = signal.^2;                    % Signal quadrieren
sigsqw = sigsqr - mean(sigsqr);        % Mittelwert subtrahieren
siglng = length(signal);               % Lnge der Sequenz
zeitbr = 0:siglng - 1;                 % Zeitbereich der Sequenz
rxschr = schritt*(1+schrittfehler);    % Schritt beim Empfnger 
schrfr = 1/rxschr;                     % Schrittfrequenz (Empf.)
costab = cos(2*pi*schrfr*zeitbr);      % cos-Tabelle
sintab = sin(2*pi*schrfr*zeitbr);      % sin-Tabelle
cosamp = sum(sigsqw.*costab)/siglng;   % cos-Amplitude
sinamp = sum(sigsqw.*sintab)/siglng;   % sin-Amplitude
phi    = angle(cosamp + i*sinamp);     % Phasenwinkel
if phi<0  phi = phi + 2*pi; end        % 0 < phi < 2*pi
abtast = round(1+rxschr*phi/(2*pi):rxschr:siglng); % Abtastpunkte
if abtast(1)==0  abtast = abtast(2:length(abtast)); end

% Darstellung
% ===========
mx = max([abs(min(signal)),abs(max(signal))]) + 0.5;
set(gcf,'Position',[1 430 800 150],'NumberTitle','off',...
        'MenuBar','none','Name','Schrittsync')
plot(zeitbr,signal)
axis([0, siglng-1, -mx, +mx])
pause
sigtast = length(vorlauf)+1:schritt:siglng;
line(sigtast-1,signal(sigtast),'LineStyle','none','Marker','.',...
     'MarkerEdgeColor','b','MarkerSize',10)
pause
line([0 siglng],[0 0],'LineStyle',':','Color',0.7*[1 1 1])
pause
line(zeitbr,sigsqr*(mx-0.5)/max(sigsqr),'Color','g')
pause
line(zeitbr,3*(cosamp*costab+sinamp*sintab),'Color','r')
pause
line(abtast-1,signal(abtast),'LineStyle','none','Marker','*',...
     'MarkerEdgeColor','r')
