% Skript zur Demonstration von V.21 mit Start/Stopp
% =================================================

% Autor:  Klaus von der Heide, e-mail:  v.d.heide@on-line.de
echo on
%
% Ein ASCII-Text von max. 32 Zeichen wird nach V.21 
% (300 Baud FSK) mit Start/Stopp-Synchronisation ber 
% die Soundkarte ausgegeben und via Mikrofon mit dem 
% Audiorecorder aufgezeichnet. Nach manueller Bearbeitung 
% der Aufnahme wird diese in MATLAB dem FSK-Empfnger 
% zugefhrt und ausgewertet.
%
% Zuerst ist der zu sendende Text einzugeben. Das 
% Eingabefenster erscheint nach Tastendruck.
%
pause %  Weiter mit beliebiger Taste
tcel = inputdlg('(maximal 32 Zeichen)','Eingabe: Zu sendender Text');
%
% Es sind zunchst die Einstellungen fr die Audioaufnahme 
% (Mikrofon) und fr die Ausgabe so einzustellen, dass 
% der Pegel bei der Aufnahme im richtigen Bereich liegt.
% ffnen Sie im Audiorecorder eine neue Datei und klicken 
% Sie dort im Men "Eigenschaften" und anschliessend 
% "Umwandeln". Stellen Sie "Format" PCM und "Atribute" 
% 8.000 Hz; 16 Bit; Mono ein und besttigen Sie mit "ok".
% 
% Die Aufnahme mit dem Audiorecorder ist nun zu starten
% und sofort anschliessend dieses Skript wieder zu 
% aktivieren durch Klick ins Fenster und beliebigen 
% Tastendruck. Folgen Sie den Anweisungen.

pause %  Weiter mit beliebiger Taste
txt  = tcel{1};                 % 
bits = str2binvec(txt);         % ASCII nach Bitvektor
fs   = 8000;                    % Abtastrate 8 kHz
flr  = fsktest(10000,1080/fs,300/fs,100/fs,bits);
%
% Stoppen Sie nun den Audiorecorder.
%
pause %  Weiter mit beliebiger Taste
%
% Prfen Sie visuell und akustisch, ob der Pegel richtig 
% liegt. Dieses Skript mit "Strg C" abbrechen und von 
% vorn beginnen, falls etwas nicht stimmt.
%
pause %  Weiter mit beliebiger Taste
%
% In der Audioaufnahme ist nun der Signal-freie Anfang 
% sowie das Ende vollstndig wegzuschneiden. Der 
% Audiorecorder bietet hierfr im Men "Bearbeiten" 
% die passenden Funktionen. Das Resultat ist nun unter 
% dem fest vorgegebenen Dateinamen "v21.wav" zu speichern.
%
pause %  Weiter mit beliebiger Taste
%
% Die Datei "v21.wav" wird nun in MATLAB eingelesen 
% und das Signal im FSK-Empfnger ausgewertet und 
% dargestellt.
%
% Das Bild Binrsignal kann mit den Tasten + - r l 
% vergrssert, verkleinert und gerollt werden. Das 
% Bild Kompexsignal lsst sich mit der Maus drehen.
%
pause %  Weiter mit beliebiger Taste
s = wavreadx('v21.wav');          % Lesen der *.wav-Datei
fskrx(s',1080/fs,300/fs,300/fs,1) % FSK-Empfnger
recbits = ans;                    % empfangene Bits
rectext = binvec2str(recbits);    % empfangener Text
pause
%
% Die Anzahl der Bitfehler sollte 0 sein:
%
pause %  Weiter mit beliebiger Taste
echo off
if length(recbits)==length(bits)
   anzbitfehler = sum(recbits~=bits) % Anzahl der Bitfehler
else
   anzbitfehler = length(bits);
   kommentar = 'Anzahl der empfangenen Bits ist falsch'
end
%
if anzbitfehler>40 
   kommentar = '  Da ist offensichtlich etwas schief gegangen'
elseif anzbitfehler>0 
   kommentar = '  Das sollte fehlerfrei laufen!'
else
   kommentar = sprintf('%3d Bits fehlerfrei bertragen !',length(recbits))
end
fh = figure;
set(fh,'NumberTitle','off','Name','Telegramm','MenuBar','none',...
    'Position',[2 576 1019 171],'Color','w')
axis([0 1,0 1])
text(-0.06,0.5,rectext,'FontSize',35,'Color','r')
set(gca,'visible','off')
echo on
%
% Bei der Datenbertragung per Audiosignal durch Luft ist zu 
% beachten, dass die Wellenlnge bei 1 kHz nur 34 cm betrgt. 
% Schon bei der bertragung ber kurze Strecken kann es zu 
% Reflexionen und damit zu Fadingeffekten kommen. Viel 
% problematischer ist die Intersymboldifferenz bei Wegunter-
% schieden in der Grssenordnung der Schrittlnge (und mehr).
% Die Schrittlnge betrgt bei 300 Baud in Luft 1.13 m.
